==> kubernetes-model-1.0.31-sources.jar: annotations/io/fabric8/openshift/api/model/UserFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.util.ArrayList;
import java.util.Map;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import java.util.HashMap;
import java.util.List;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class UserFluentImpl<T extends UserFluent<T>> extends BaseFluent<T> implements UserFluent<T>{

     User.ApiVersion apiVersion;     String fullName;     List<String> groups = new ArrayList();     List<String> identities = new ArrayList();     String kind;     VisitableBuilder<ObjectMeta, ?> metadata;     Map<String, Object> additionalProperties = new HashMap();

    public User.ApiVersion getApiVersion(){
    return this.apiVersion;
    }
    public T withApiVersion( User.ApiVersion apiVersion){
    this.apiVersion=apiVersion; return (T) this;
    }
    public String getFullName(){
    return this.fullName;
    }
    public T withFullName( String fullName){
    this.fullName=fullName; return (T) this;
    }
    public T addToGroups( String ...items){
    for (String item : items) {this.groups.add(item);} return (T)this;
    }
    public T removeFromGroups( String ...items){
    for (String item : items) {this.groups.remove(item);} return (T)this;
    }
    public List<String> getGroups(){
    return this.groups;
    }
    public T withGroups( List<String> groups){
    this.groups.clear();if (groups != null) {for (String item : groups){this.addToGroups(item);}} return (T) this;
    }
    public T withGroups( String ...groups){
    this.groups.clear(); if (groups != null) {for (String item :groups){ this.addToGroups(item);}} return (T) this;
    }
    public T addToIdentities( String ...items){
    for (String item : items) {this.identities.add(item);} return (T)this;
    }
    public T removeFromIdentities( String ...items){
    for (String item : items) {this.identities.remove(item);} return (T)this;
    }
    public List<String> getIdentities(){
    return this.identities;
    }
    public T withIdentities( List<String> identities){
    this.identities.clear();if (identities != null) {for (String item : identities){this.addToIdentities(item);}} return (T) this;
    }
    public T withIdentities( String ...identities){
    this.identities.clear(); if (identities != null) {for (String item :identities){ this.addToIdentities(item);}} return (T) this;
    }
    public String getKind(){
    return this.kind;
    }
    public T withKind( String kind){
    this.kind=kind; return (T) this;
    }
    public ObjectMeta getMetadata(){
    return this.metadata!=null?this.metadata.build():null;
    }
    public T withMetadata( ObjectMeta metadata){
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (T) this;
    }
    public MetadataNested<T> withNewMetadata(){
    return new MetadataNestedImpl<T>();
    }
    public MetadataNested<T> withNewMetadataLike( ObjectMeta item){
    return new MetadataNestedImpl<T>(item);
    }
    public MetadataNested<T> editMetadata(){
    return withNewMetadataLike(getMetadata());
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
UserFluentImpl that = (UserFluentImpl) o;
if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
if (fullName != null ? !fullName.equals(that.fullName) :that.fullName != null) return false;
if (groups != null ? !groups.equals(that.groups) :that.groups != null) return false;
if (identities != null ? !identities.equals(that.identities) :that.identities != null) return false;
if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<MetadataNested<N>> implements MetadataNested<N>{

        private final ObjectMetaBuilder builder;
    
             MetadataNestedImpl (){
        this.builder = new ObjectMetaBuilder(this);
        }
             MetadataNestedImpl ( ObjectMeta item){
        this.builder = new ObjectMetaBuilder(this, item);
        }
    
            public N and(){
            return (N) UserFluentImpl.this.withMetadata(builder.build());
        }
            public N endMetadata(){
            return and();
        }
    
}


}

==> kubernetes-model-1.0.33-sources.jar: annotations/io/fabric8/openshift/api/model/UserFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.util.ArrayList;
import java.util.Map;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import java.util.HashMap;
import java.util.List;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class UserFluentImpl<T extends UserFluent<T>> extends BaseFluent<T> implements UserFluent<T>{

     User.ApiVersion apiVersion;     String fullName;     List<String> groups = new ArrayList();     List<String> identities = new ArrayList();     String kind;     VisitableBuilder<ObjectMeta, ?> metadata;     Map<String, Object> additionalProperties = new HashMap();
public UserFluentImpl(){
    
}
public UserFluentImpl( User instance ){
    this.withApiVersion(instance.getApiVersion()); this.withFullName(instance.getFullName()); this.withGroups(instance.getGroups()); this.withIdentities(instance.getIdentities()); this.withKind(instance.getKind()); this.withMetadata(instance.getMetadata()); 
}

    public User.ApiVersion getApiVersion(){
    return this.apiVersion;
    }
    public T withApiVersion( User.ApiVersion apiVersion){
    this.apiVersion=apiVersion; return (T) this;
    }
    public String getFullName(){
    return this.fullName;
    }
    public T withFullName( String fullName){
    this.fullName=fullName; return (T) this;
    }
    public T addToGroups( String ...items){
    for (String item : items) {this.groups.add(item);} return (T)this;
    }
    public T removeFromGroups( String ...items){
    for (String item : items) {this.groups.remove(item);} return (T)this;
    }
    public List<String> getGroups(){
    return this.groups;
    }
    public T withGroups( List<String> groups){
    this.groups.clear();if (groups != null) {for (String item : groups){this.addToGroups(item);}} return (T) this;
    }
    public T withGroups( String ...groups){
    this.groups.clear(); if (groups != null) {for (String item :groups){ this.addToGroups(item);}} return (T) this;
    }
    public T addToIdentities( String ...items){
    for (String item : items) {this.identities.add(item);} return (T)this;
    }
    public T removeFromIdentities( String ...items){
    for (String item : items) {this.identities.remove(item);} return (T)this;
    }
    public List<String> getIdentities(){
    return this.identities;
    }
    public T withIdentities( List<String> identities){
    this.identities.clear();if (identities != null) {for (String item : identities){this.addToIdentities(item);}} return (T) this;
    }
    public T withIdentities( String ...identities){
    this.identities.clear(); if (identities != null) {for (String item :identities){ this.addToIdentities(item);}} return (T) this;
    }
    public String getKind(){
    return this.kind;
    }
    public T withKind( String kind){
    this.kind=kind; return (T) this;
    }
    public ObjectMeta getMetadata(){
    return this.metadata!=null?this.metadata.build():null;
    }
    public T withMetadata( ObjectMeta metadata){
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (T) this;
    }
    public MetadataNested<T> withNewMetadata(){
    return new MetadataNestedImpl<T>();
    }
    public MetadataNested<T> withNewMetadataLike( ObjectMeta item){
    return new MetadataNestedImpl<T>(item);
    }
    public MetadataNested<T> editMetadata(){
    return withNewMetadataLike(getMetadata());
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
UserFluentImpl that = (UserFluentImpl) o;
if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
if (fullName != null ? !fullName.equals(that.fullName) :that.fullName != null) return false;
if (groups != null ? !groups.equals(that.groups) :that.groups != null) return false;
if (identities != null ? !identities.equals(that.identities) :that.identities != null) return false;
if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<MetadataNested<N>> implements MetadataNested<N>{

        private final ObjectMetaBuilder builder;
    
             MetadataNestedImpl ( ObjectMeta item){
        this.builder = new ObjectMetaBuilder(this, item);
        }
             MetadataNestedImpl (){
        this.builder = new ObjectMetaBuilder(this);
        }
    
            public N and(){
            return (N) UserFluentImpl.this.withMetadata(builder.build());
        }
            public N endMetadata(){
            return and();
        }
    
}


}
